==> ktorrent-4.3.1.tar.xz: ktorrent-4.3.1/plugins/search/opensearchdownloadjob.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef KTOPENSEARCHDOWNLOADJOB_H
#define KTOPENSEARCHDOWNLOADJOB_H

#include <kio/job.h>
#include <KUrl>

namespace kt
{

	/**
		Job which tries to find an opensearch xml description on a website and 
		download that to a directory.
	*/
	class OpenSearchDownloadJob : public KIO::Job
	{
		Q_OBJECT
	public:
		OpenSearchDownloadJob(const KUrl & url,const QString & dir);
		virtual ~OpenSearchDownloadJob();

		/// Start the job
		void start();
		
		/// Get the directory 
		QString directory() const {return dir;}
		
		/// Get the hostname
		QString hostname() const {return url.host();}
		
	private slots:
		void getFinished(KJob* j);
		void xmlFileDownloadFinished(KJob* j);
		
	private:
		bool checkLinkTagContent(const QString & content);
		QString htmlParam(const QString & param,const QString & content);
		
	private:
		KUrl url;
		QString dir;
	};

}

#endif

==> ktorrent-5.0.1.tar.xz: ktorrent-5.0.1/plugins/search/opensearchdownloadjob.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef KTOPENSEARCHDOWNLOADJOB_H
#define KTOPENSEARCHDOWNLOADJOB_H

#include <kio/job.h>
#include <QUrl>

namespace kt
{

    /**
        Job which tries to find an opensearch xml description on a website and
        download that to a directory.
    */
    class OpenSearchDownloadJob : public KIO::Job
    {
        Q_OBJECT
    public:
        OpenSearchDownloadJob(const QUrl &url, const QString& dir);
        virtual ~OpenSearchDownloadJob();

        /// Start the job
        void start();

        /// Get the directory
        QString directory() const {return dir;}

        /// Get the hostname
        QString hostname() const {return url.host();}

    private slots:
        void getFinished(KJob* j);
        void xmlFileDownloadFinished(KJob* j);

    private:
        bool checkLinkTagContent(const QString& content);
        QString htmlParam(const QString& param, const QString& content);

    private:
        QUrl url;
        QString dir;
    };

}

#endif
